==> the-duke-1.9.1.tgz: package/CHANGELOG.md <==
# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## Unreleased

## [1.9.1] - 2017-12-14
### Fixed
- Compose structure returned an object if there were errors in non-allowed fields but an array was expected. Resolved by wrapping the result object into an array.

## [1.9.0] - 2017-12-07
### Added
- adds quality score enrichment.
- adds spatial coverage enrichment.

## [1.8.0] - 2017-10-09
### Added
- adds `deleted` field to the default namespace to logically delete a dataset

## [1.7.1] - 2017-10-04
### Added
- XML data can now be parsed with tag attributes too.
- adds `retries` and `lastRetriedAt` fields to default.composeStatus

## [1.6.1] - 2017-10-04
### Added
- updated package-lock.json for changes in 1.6.0

## [1.6.0] - 2017-10-04
### Added
- adds `default.groupIds` in the compose step

## [1.5.6] - 2017-09-19
### Fixed
- dataset.layers fixed - Consolidated dataset was not able to load layers properly due to default argument in composeDataset function.
- dataset.extent always comes from the item and never from the layer

## [1.5.5] - 2017-09-18
### Fixed
- Computing default id had a bug. Resolved it to handle ternary operator when layer.id = 0

## [1.5.4] - 2017-09-15
### Fixed
- Compose structure returns default no matter what. When an item itself is unavailable, default field is added and its composeStatus.pass is set to false.

## [1.5.3] - 2017-09-14
### Changed
- Compose structure streamlined for all types of datasets including capturing error. Refer to readme for details

## [1.4.3] - 2017-09-12
### Changed
- Compose step. Different parts of the dataset are fetched async and assembled into a dataset schema as defined in readme.

## [1.3.3] - 2017-09-06
### Fixed
- child datasets are composed correctly

## [1.3.2] - 2017-09-06
### Fixed
- metadata source fallback to item.owner

## [1.3.1] - 2017-09-06
### Fixed
- itemName can no longer be null
- hubType is assigned correctly for non datasets


## [1.3.0] - 2017-09-05
### Added
- hub type determined during compose
- metadata source during compose
### Changed
- use src/index for rollup entrypoint
- export composeDataset

## [1.2.0] - 2017-08-31
### Added
- Reverse geocoding enrichment added. It gets country, states, counties based on the extent of the dataset
### Changed
- Travis CI does not run tests that are dependent on live servers/api

## [1.1.0] - 2017-08-29
### Changed
- Layers are returned along with the composed dataset as an array of datasets.

## [1.0.0] - 2017-08-22
### Changed
- Enrichments are returned as partial results and not the entire datasets.

==> the-duke-1.10.0.tgz: package/CHANGELOG.md <==
# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## Unreleased

## [1.10.0] - 2018-01-09
### Added
- dataset compose handles single layer items (the layers array will have one layer object inside which is the layer that the item references)

## [1.9.2] - 2017-12-20
### Fixed
- tag enrichment method sent the request with unscaped tag names. Resolved by escaping tag names before send the request.

## [1.9.1] - 2017-12-14
### Fixed
- compose function returned an object if there were errors in non-allowed fields but an array was expected. Resolved by wrapping the result object into an array.

## [1.9.0] - 2017-12-07
### Added
- adds quality score enrichment.
- adds spatial coverage enrichment.

## [1.8.0] - 2017-10-09
### Added
- adds `deleted` field to the default namespace to logically delete a dataset

## [1.7.1] - 2017-10-04
### Added
- XML data can now be parsed with tag attributes too.
- adds `retries` and `lastRetriedAt` fields to default.composeStatus

## [1.6.1] - 2017-10-04
### Added
- updated package-lock.json for changes in 1.6.0

## [1.6.0] - 2017-10-04
### Added
- adds `default.groupIds` in the compose step

## [1.5.6] - 2017-09-19
### Fixed
- dataset.layers fixed - Consolidated dataset was not able to load layers properly due to default argument in composeDataset function.
- dataset.extent always comes from the item and never from the layer

## [1.5.5] - 2017-09-18
### Fixed
- Computing default id had a bug. Resolved it to handle ternary operator when layer.id = 0

## [1.5.4] - 2017-09-15
### Fixed
- Compose structure returns default no matter what. When an item itself is unavailable, default field is added and its composeStatus.pass is set to false.

## [1.5.3] - 2017-09-14
### Changed
- Compose structure streamlined for all types of datasets including capturing error. Refer to readme for details

## [1.4.3] - 2017-09-12
### Changed
- Compose step. Different parts of the dataset are fetched async and assembled into a dataset schema as defined in readme.

## [1.3.3] - 2017-09-06
### Fixed
- child datasets are composed correctly

## [1.3.2] - 2017-09-06
### Fixed
- metadata source fallback to item.owner

## [1.3.1] - 2017-09-06
### Fixed
- itemName can no longer be null
- hubType is assigned correctly for non datasets


## [1.3.0] - 2017-09-05
### Added
- hub type determined during compose
- metadata source during compose
### Changed
- use src/index for rollup entrypoint
- export composeDataset

## [1.2.0] - 2017-08-31
### Added
- Reverse geocoding enrichment added. It gets country, states, counties based on the extent of the dataset
### Changed
- Travis CI does not run tests that are dependent on live servers/api

## [1.1.0] - 2017-08-29
### Changed
- Layers are returned along with the composed dataset as an array of datasets.

## [1.0.0] - 2017-08-22
### Changed
- Enrichments are returned as partial results and not the entire datasets.
